# vaccination.py

Get COVID-19 vaccination schedules from booking.moh.gov.ge in the CLI.

![PyPI](https://img.shields.io/pypi/v/vaccination)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/vaccination)
![PyPI - Downloads](https://img.shields.io/pypi/dm/vaccination)
![PyPI - License](https://img.shields.io/pypi/l/vaccination)

[![asciicast](https://asciinema.org/a/434144.svg)](https://asciinema.org/a/434144)

## Installation
```bash
$ pip install vaccination
```

## Usage

Make sure the Python bin directory is added to your `PATH`

```bash
$ vaccination
```

## Changelog

Please see [CHANGELOG](CHANGELOG.md) for details.

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## Authors

- [**Temuri Takalandze**](https://abgeo.dev) - *Initial work*

## License

Copyright © 2021 [Temuri Takalandze](https://abgeo.dev).  
Released under the [MIT](LICENSE) license.
